import { Construct } from "constructs";
import { IMachineImage, InstanceClass, InstanceSize, InstanceType, ISubnet, IVpc } from "aws-cdk-lib/aws-ec2";
import { Duration, RemovalPolicy, Size } from "aws-cdk-lib";
import { IKey } from "aws-cdk-lib/aws-kms";
import { IHostedZone } from "aws-cdk-lib/aws-route53";
/**
 * Properties for WordPressInstance.
 */
export interface WordPressInstanceProps {
    /**
     * Vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpc?: IVpc;
    /**
     * Name of the vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcName?: string;
    /**
     * ID of the vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcId?: string;
    /**
     * Subnet to place the volume and instance in.
     * One of subnet or subnetId is required.
     */
    readonly subnet?: ISubnet;
    /**
     * ID of subnet to place the volume and instance in.
     * One of subnet or subnetId is required.
     */
    readonly subnetId?: string;
    /**
     * Availability zone to deploy the instance and volume in.
     */
    readonly availabilityZone: string;
    /**
     * Instance type to use of the instance. A t4g.small is used if not provided.
     */
    readonly instanceType?: InstanceType;
    /**
     * Instance class to use.
     *
     * @default - InstanceClass.BURSTABLE4_GRAVITON
     */
    readonly instanceClass?: InstanceClass;
    /**
     * Instance size to use.
     *
     * @default - InstanceSize.SMALL
     */
    readonly instanceSize?: InstanceSize;
    /**
     * Optional instance name.
     */
    readonly instanceName?: string;
    /**
     * Propagate the EC2 instance tags to the EBS volumes.
     *
     * @default - true
     */
    readonly propagateTagsToVolumeOnCreation?: boolean;
    /**
     * OS volume size in Gigabytes.
     *
     * @default - Size.gigabytes(10)
     */
    readonly osVolumeSize?: Size;
    /**
     * Data volume size in Gigabytes.
     *
     * @default - Size.gigabytes(10)
     */
    readonly dataVolumeSize?: Size;
    /**
     * Data volume removal policy.
     *
     * @default - RemovalPolicy.RETAIN
     */
    readonly dataVolumeRemovalPolicy?: RemovalPolicy;
    /**
     * Encryption key to use for volumes.
     */
    readonly encryptionKey?: IKey;
    /**
     * The domain names of the sites to be hosted by this instance.
     * Each provided site will be a separate WordPress installation.
     */
    readonly sites: string[];
    /**
     * Prefix for the DNS record pointing to the EC2 instance.
     */
    readonly hostPrefix?: string;
    /**
     * the zone for the DNS record pointing to the EC2 instance.
     */
    readonly hostZone?: IHostedZone | string;
    /**
     * The TTL to use on the DNS record pointing to the EC2 instance.
     *
     * @default - Duration.seconds(300)
     */
    readonly hostRecordTtl?: Duration;
}
export declare const DEFAULT_ARM_IMAGE_SSM_PARAMETER = "/aws/service/canonical/ubuntu/server/jammy/stable/current/arm64/hvm/ebs-gp2/ami-id";
export declare const DEFAULT_AMD64_IMAGE_SSM_PARAMETER = "/aws/service/canonical/ubuntu/server/jammy/stable/current/amd64/hvm/ebs-gp2/ami-id";
/**
 * Creates a new WordPress instance.
 */
export declare class WordPressInstance extends Construct {
    resolveVpc(scope: Construct, props: WordPressInstanceProps): IVpc;
    resolveInstanceType(scope: Construct, props: WordPressInstanceProps): InstanceType;
    resolveSubnet(scope: Construct, props: WordPressInstanceProps): ISubnet;
    resolveMachineImage(instanceType: InstanceType): IMachineImage;
    constructor(scope: Construct, id: string, props: WordPressInstanceProps);
}
